@@ -120,7 +120,7 @@ class Image:
     def __str__(self) -> str: return self.name
     def copy(self):
         '''Returns a copy of itself'''
-        return Image(self.nom, copy.deepcopy(self.img))
+        return Image(self.name, copy.deepcopy(self.img))
     def size(self, rev=False) -> list[int]:
         '''Returns Image's size (reverse True means [y,x] whereas False means [x,y])'''
         return [len(self.img[0]), len(self.img)][::-1 if rev else 1]
